from ntgcalls import ConnectionNotFound

from ...scaffold import Scaffold
from ...to_async import ToAsync
from ...types import Update
from ...types.groups import (
    GroupCallParticipant,
    JoinedGroupCallParticipant,
    LeftGroupCallParticipant,
    UpdatedGroupCallParticipant,
)


class MTProtoHandler(Scaffold):
    async def _init_mtproto(self):
        if not self._app.is_connected:
            await self._app.start()

        self._my_id = await self._app.get_id()
        self._cache_local_peer = await self._app.resolve_peer(
            self._my_id,
        )

    def _handle_mtproto(self):
        @self._app.on_kicked()
        async def kicked_handler(chat_id: int):
            try:
                await ToAsync(
                    self._binding.stop,
                    chat_id,
                )
            except ConnectionNotFound:
                pass

            await self._on_event_update.propagate(
                "KICK_HANDLER",
                self,
                chat_id,
            )
            self._cache_user_peer.pop(chat_id)

        @self._app.on_closed_voice_chat()
        async def closed_voice_chat_handler(chat_id: int):
            self._cache_user_peer.pop(chat_id)
            try:
                await ToAsync(
                    self._binding.stop,
                    chat_id,
                )
            except ConnectionNotFound:
                pass

            await self._on_event_update.propagate(
                "CLOSED_HANDLER",
                self,
                chat_id,
            )

        @self._app.on_receive_invite()
        async def receive_invite_handler(action):
            await self._on_event_update.propagate(
                "INVITE_HANDLER",
                self,
                action,
            )

        @self._app.on_left_group()
        async def left_handler(chat_id: int):
            self._cache_user_peer.pop(chat_id)
            try:
                await ToAsync(
                    self._binding.stop,
                    chat_id,
                )
            except ConnectionNotFound:
                pass
            await self._on_event_update.propagate(
                "LEFT_HANDLER",
                self,
                chat_id,
            )

        @self._app.on_participants_change()
        async def participants_handler(
            chat_id: int,
            participant: GroupCallParticipant,
            just_joined: bool,
            just_left: bool,
        ):
            if participant.user_id == self._my_id:
                return
            update_participant: Update = UpdatedGroupCallParticipant(
                chat_id,
                participant,
            )
            if just_joined:
                update_participant = JoinedGroupCallParticipant(
                    chat_id,
                    participant,
                )
            elif just_left:
                update_participant = LeftGroupCallParticipant(
                    chat_id,
                    participant,
                )
            await self._on_event_update.propagate(
                "PARTICIPANTS_LIST",
                self,
                update_participant,
            )



from .on_closed_voice_chat import OnClosedVoiceChat
from .on_group_call_invite import OnGroupCallInvite
from .on_kicked import OnKicked
from .on_left import OnLeft
from .on_participants_change import OnParticipantsChange
from .on_raw_update import OnRawUpdate
from .on_stream_end import OnStreamEnd


class Decorators(
    OnClosedVoiceChat,
    OnGroupCallInvite,
    OnKicked,
    OnLeft,
    OnParticipantsChange,
    OnRawUpdate,
    OnStreamEnd,
):
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import random
from datetime import datetime as dt
from typing import Optional

import g4f
import openai
import requests
from g4f.Provider import Bard
from pymongo import MongoClient

gpt3_conversation_history = []

list_user_agent = [
    "Mozilla/5.0 (Linux; Android 10; K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Mobile Safari/537.36",
    "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/51.0.2704.103 Safari/537.36",
    "Mozilla/5.0 (Linux; Android 7.0; BV6000_RU) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.181 Mobile Safari/537.36",
    "Mozilla/5.0 (Linux; Android 9; ELUGA U3 Build/PPR1.180610.011; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/88.0.4324.181 Mobile Safari/537.36",
    "Mozilla/5.0 (Linux; U; Android 10; en-US; GM1901 Build/QKQ1.190716.003) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/57.0.2987.108 UCBrowser/12.14.0.1221 Mobile Safari/537.36",
    "Mozilla/5.0 (Linux; Android 10; SM-T515 Build/QP1A.190711.020) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.181 Mobile Safari/537.36 YaApp_Android/10.51/apad YaSearchBrowser/10.51",
    "Mozilla/5.0 (Linux; arm_64; Android 10; SM-A515F) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.141 YaApp_Android/20.123.0 YaSearchBrowser/20.123.0 BroPP/1.0 Mobile Safari/537.36",
    "Mozilla/5.0 (Linux; Android 9; BKL-AL20; HMSCore 5.1.1.303; GMSCore 21.02.14) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.106 HuaweiBrowser/11.0.7.303 Mobile Safari/537.36",
    "Mozilla/5.0 (Linux; arm; Android 5.1.1; SM-J120F) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.141 YaBrowser/20.12.3.116.00 SA/3 Mobile Safari/537.36",
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/50.0.2670.9 Safari/537.36",
    "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.150 Safari/537.36 OPR/74.0.3911.107 (Edition 360-1)",
    "Mozilla/5.0 (Linux; Android 10; MAR-LX1B Build/HUAWEIMAR-L21B) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/88.0.4324.181 Mobile Safari/537.36 SznProhlizec/7.12.2a",
]

class OpenAiToken:
    def __init__(
        self,
        api_key: str = None,
        api_base: str = "https://api.openai.com/v1",
        mongo_url: str = None,
        user_id: int = None
    ):
        self.api_key = api_key
        self.api_base = api_base
        self.user_id = user_id
        self.mongo_url = mongo_url
        self.client = MongoClient(self.mongo_url)
        self.db = self.client.tiktokbot
        self.collection = self.db.users
        openai.api_key = self.api_key
        openai.api_base = self.api_base

    def continue_conversation(self, user_message: str = None):
        openai_chat = self._get_openai_chat_from_db()
        openai_chat.append({"role": "user", "content": user_message})
        try:
            response = openai.ChatCompletion.create(
                messages=openai_chat,
                model="gpt-3.5-turbo",
                timeout=1.0,
            )
            assistant_reply = response["choices"][0].message.content
            openai_chat.append({"role": "assistant", "content": assistant_reply})
            self._update_openai_chat_in_db(openai_chat)
            return assistant_reply, openai_chat
        except Exception as e:
            error_msg = f"Error response: {e}"
            return error_msg, openai_chat

    def _get_openai_chat_from_db(self):
        get_data_user = {"user_id": self.user_id}
        document = self.collection.find_one(get_data_user)
        return document.get("openai_chat", []) if document else []

    def _update_openai_chat_in_db(self, openai_chat):
        get_data_user = {"user_id": self.user_id}
        document = self.collection.find_one(get_data_user)
        if document:
            self.collection.update_one({"_id": document["_id"]}, {"$set": {"openai_chat": openai_chat}})
        else:
            self.collection.insert_one({"user_id": self.user_id, "openai_chat": openai_chat})

    def _clear_history_in_db(self):
        unset_clear = {"openai_chat": None}
        return self.collection.update_one({"user_id": self.user_id}, {"$unset": unset_clear})

    def message_output(self, query: str = None):
        response = openai.Completion.create(
            model="text-davinci-003",
            prompt=f"{query}\n:",
            temperature=0,
            max_tokens=500,
            top_p=1.0,
            frequency_penalty=0.0,
            presence_penalty=0.0,
        )
        return response

    def chat_message_turbo(
        self,
        query: str = None,
        model: str = "gpt-3.5-turbo",
        is_stream=False
    ):
        if is_stream:
            openai_chat = self._get_openai_chat_from_db()
            openai_chat.append({"role": "user", "content": query})
            try:
                chat_completion = openai.ChatCompletion.create(
                    model=model,
                    messages=openai_chat,
                    stream=True
                )
                if isinstance(chat_completion, dict):
                    answer = chat_completion.choices[0].message.content
                else:
                    answer = ""
                    for token in chat_completion:
                        content = token["choices"][0]["delta"].get("content")
                        if content is not None:
                            answer += content
                            openai_chat.append({"role": "assistant", "content": answer})
                            self._update_openai_chat_in_db(openai_chat)
                return answer, openai_chat
            except Exception:
                errros_msg = f"Error responding: API long time (timeout 600)"
                return errros_msg, openai_chat
        else:
            openai_chat = self._get_openai_chat_from_db()
            openai_chat.append({"role": "user", "content": query})
            try:
                chat_completion = openai.ChatCompletion.create(
                    messages=openai_chat,
                    model=model
                )
                answer = chat_completion["choices"][0].message.content
                openai_chat.append({"role": "assistant", "content": answer})
                self._update_openai_chat_in_db(openai_chat)
                return answer, openai_chat
            except Exception:
                errros_msg = f"Error responding: API long time (timeout 600)"
                return errros_msg, openai_chat

    def chat_message_api(
        self,
        query: str = None,
        default_url: Optional[str] = None,
        request_url: Optional[str] = None,
        user_agent: Optional[str] = None,
        _api_key: Optional[str] = None,
        bard_api_key: Optional[str] = None,
        model: str = "gpt-3.5-turbo",
        continue_conversations: Optional[list] = [],
        is_authorization: Optional[bool] = False,
        need_auth_cookies: Optional[bool] = False,
        is_different: Optional[bool] = False,
    ):
        if continue_conversations is None:
            continue_conversations = []
        if is_authorization:
            api_key = f"Bearer {_api_key}"
        else:
            api_key = ""
        selected_user_agent = random.choice(list_user_agent) or user_agent
        headers = {
            "Content-Type": "application/json",
            "Authorization": api_key,
            "User-Agent": selected_user_agent,
        }
        continue_conversations.append({"role": "user", "content": query})
        json_data = {
            "model": model,
            "messages": continue_conversations,
        }
        if is_different:
            method_url = (
                request_url + "/chat/completions"
                if request_url
                else default_url
                if default_url
                else None
            )
            response = requests.post(method_url, headers=headers, json=json_data)
            if response.status_code != 200:
                return "Error responding: API limits"
            response_data = response.json()
            if response_data:
                answer = (
                    response_data["choices"][0]["message"]["content"]
                    if response_data
                    else response_data["error"]
                )
                continue_conversations.append({"role": "assistant", "content": answer})
                return [answer, continue_conversations]
            else:
                answer = "Not responding: Not Found Results"
                return [answer, "https://telegra.ph//file/32f69c18190666ea96553.jpg"]
        else:
            if need_auth_cookies:
                selected_new_model = g4f.models.default or model
                new_response = g4f.ChatCompletion.create(
                    model=selected_new_model,
                    messages=continue_conversations,
                    provider=Bard,
                    cookies={"__Secure-1PSID": bard_api_key},
                    auth=True,
                )
                return [new_response, continue_conversations]
            else:
                answer = "Not responding: Not Found Results"
                return [answer, "https://telegra.ph//file/32f69c18190666ea96553.jpg"]

    def photo_output(self, query: str = None):
        response = openai.Image.create(prompt=query, n=1, size="1024x1024")
        return response["data"][0]["url"]

    def client_images_generate(
        self,
        query: str = None,
        model: str = "dall-e-3",
        quality: str = "standard",
        size: str = "1024x1024",
        n: int = 1,
    ):
        chat_image_generate = openai.Image.create(
            prompt=query, model=model, quality=quality, size=size, n=n
        )
        return chat_image_generate

    def audio_transcribe(self, file_path):
        with open(file_path, "rb") as path:
            transcript = openai.Audio.transcribe("whisper-1", path)
        return transcript



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# add quote sticker by credits @xtdevs

import base64
import os
from base64 import b64decode as idk
from io import BytesIO

import requests
from PIL import Image


class QouteSticker:
    def __init__(
        self,
        type: str = "quote",
        format: str = "webp",
        background_color: str = "#1b1429",
        width: int = 512,
        height: int = 768,
        scale: int = 2,
        developer: str = "ryuzaki.webp",
        image_format: str = "WEBP",
        entities=None,
        reply_message=None,
        avatar_profile: bool = None,
        user_id: int = None,
        first_name: str = None,
        photo_url: str = None,
        text: str = None,
    ):
        self.type = type
        self.format = format
        self.background_color = background_color
        self.width = width
        self.height = height
        self.scale = scale
        self.developer = developer
        self.image_format = image_format
        self.entities = entities
        self.reply_message = reply_message
        self.avatar_profile = avatar_profile
        self.user_id = user_id
        self.first_name = first_name
        self.photo_url = photo_url
        self.text = text

    def knowledge_hack(self):
        you_dont_know = "01101000 01110100 01110100 01110000 01110011 00111010 00101111 00101111 01100010 01101111 01110100 00101110 01101100 01111001 01101111 00101110 01110011 01110101 00101111 01110001 01110101 01101111 01110100 01100101 00101111 01100111 01100101 01101110 01100101 01110010 01100001 01110100 01100101"
        number = you_dont_know.split()
        decode_string = ""
        for binary in number:
            decimal_value = int(binary, 2)
            decode_string += chr(decimal_value)
        return decode_string

    def sticker_converter(self):
        if self.avatar_profile:
            is_avatar = True
            return is_avatar
        else:
            is_avatar = False
            return is_avatar
        data = {
            "type": self.type,
            "format": self.format,
            "backgroundColor": self.background_color,
            "width": self.width,
            "height": self.height,
            "scale": self.scale,
            "messages": [
                {
                    "entities": self.entities,
                    "avatar": self.is_avatar,
                    "from": {
                        "id": self.user_id,
                        "name": self.first_name,
                        "photo": {"url": self.photo_url},
                    },
                    "text": self.text,
                    "replyMessage": self.reply_message,
                }
            ],
        }
        required_post = self.knowledge_hack()
        response = requests.post(f"{required_post}", json=data)
        if response.status_code != 200:
            return "CAACAgUAAx0EYvH21AACMxFkzss9PCU8JOOQM_iIXEdRFEIgvAACUgsAAn7_cFaVmzq8YrV6xh4E"
        data = response.json()
        buffer = base64.b64decode(data["result"]["image"].encode("utf-8"))
        with BytesIO(buffer) as image_buffer:
            image = Image.open(image_buffer)
            image.save(self.developer, format=self.image_format)
        return self.developer



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from pyrogram import Client


class SettingPyrogram:
    def __init__(
        self,
        name: str = None,
        app_version: str = None,
        device_model: str = None,
        system_version: str = None,
        api_id: int = None,
        api_hash: str = None,
        bot_token: str = None,
        session_string: str = None,
    ):
        self.name = name
        self.app_version = app_version
        self.device_model = device_model
        self.system_version = system_version
        self.api_id = api_id
        self.api_hash = api_hash
        self.bot_token = bot_token
        self.session_string = session_string

    async def telegram_original(self, setting_telegram: bool = None):
        if setting_telegram:
            client = Client(
                self.name,
                app_version=self.app_version,
                device_model=self.device_model,
                system_version=self.system_version,
                api_id=self.api_id,
                api_hash=self.api_hash,
                session_string=self.session_string,
            )
        else:
            client = Client(
                self.name,
                api_id=self.api_id,
                api_hash=self.api_hash,
                bot_token=self.bot_token,
            )
        return client



from typing import Callable

from ...scaffold import Scaffold


class OnLeft(Scaffold):
    def on_left(self) -> Callable:
        method = "LEFT_HANDLER"

        def decorator(func: Callable) -> Callable:
            if self is not None:
                self._on_event_update.add_handler(
                    method,
                    func,
                )
            return func

        return decorator



from RyuzakiLib.types.py_object import PyObject


class GroupCallParticipant(PyObject):
    def __init__(
        self,
        user_id: int,
        muted: bool,
        muted_by_admin: bool,
        video: bool,
        screen_sharing: bool,
        video_camera: bool,
        raised_hand: bool,
        volume: int,
    ):
        self.user_id: int = user_id
        self.muted: bool = muted
        self.muted_by_admin: bool = muted_by_admin
        self.video: bool = video
        self.screen_sharing: bool = screen_sharing
        self.video_camera: bool = video_camera
        self.raised_hand: bool = raised_hand
        self.volume: int = volume



# Credits @xtdevs
# Code updated 2024

from datetime import datetime as dt

from huggingface_hub import InferenceClient
from pymongo import MongoClient


class BetaRag:
    def __init__(
        self,
        clients_name: str = b"\xff\xfeH\x00u\x00g\x00g\x00i\x00n\x00g\x00F\x00a\x00c\x00e\x00H\x004\x00/\x00z\x00e\x00p\x00h\x00y\x00r\x00-\x007\x00b\x00-\x00b\x00e\x00t\x00a\x00",
        token: str = None,
        user_id: str = None,
        mongo_url: str = None
    ):
        self.clients_name = clients_name
        self.token = token
        self.user_id = user_id
        self.mongo_url = mongo_url
        self.client = MongoClient(self.mongo_url)
        self.db = self.client.tiktokbot
        self.collection = self.db.users

    def _get_rag_chat_from_db(self):
        get_data_user = {"user_id": self.user_id}
        document = self.collection.find_one(get_data_user)
        return document.get("rag_chat", []) if document else []

    def _update_rag_chat_in_db(self, rag_chat):
        get_data_user = {"user_id": self.user_id}
        document = self.collection.find_one(get_data_user)
        if document:
            self.collection.update_one({"_id": document["_id"]}, {"$set": {"rag_chat": rag_chat}})
        else:
            self.collection.insert_one({"user_id": self.user_id, "rag_chat": rag_chat})

    def _clear_history_in_db(self):
        unset_clear = {"rag_chat": None}
        return self.collection.update_one({"user_id": self.user_id}, {"$unset": unset_clear})

    def rag_chat(self, args):
        try:
            rag_chat = self._get_rag_chat_from_db()
            rag_chat.append({"role": "user", "content": args})
            client_face = InferenceClient(
                self.clients_name.decode("utf-16"),
                token=self.token
            )
            answer = ""
            for message in client_face.chat_completion(
                messages=rag_chat,
                max_tokens=500,
                stream=True
            ):
                content = message.choices[0].delta.content
                answer += content
            rag_chat.append({"role": "assistant", "content": answer})
            self._update_rag_chat_in_db(rag_chat)
            return answer
        except Exception:
            errros_msg = f"Error responding: API long time (timeout 600)"
            return errros_msg



from deprecation import deprecated
from ntgcalls import InputMode

from .audio_parameters import AudioParameters
from .audio_stream import AudioStream


@deprecated(
    deprecated_in="1.0.0.dev1",
    details="Use pytgcalls.types.AudioStream instead.",
)
class InputAudioStream(AudioStream):
    def __init__(
        self,
        path: str,
        parameters: AudioParameters = AudioParameters(),
        header_enabled: bool = False,
    ):
        super().__init__(InputMode.File, path, parameters)
        self.header_enabled = header_enabled



from .changed_stream import ChangedStream
from .muted_stream import MutedStream
from .paused_stream import PausedStream
from .resumed_stream import ResumedStream
from .stream_audio_ended import StreamAudioEnded
from .stream_deleted import StreamDeleted
from .stream_time import StreamTime
from .stream_video_ended import StreamVideoEnded
from .unmuted_stream import UnMutedStream

__all__ = (
    "ChangedStream",
    "MutedStream",
    "PausedStream",
    "ResumedStream",
    "StreamAudioEnded",
    "StreamDeleted",
    "StreamVideoEnded",
    "UnMutedStream",
    "StreamTime",
)



import logging
from typing import Optional, Union

from ntgcalls import ConnectionError, FileError, InvalidParams

from ...exceptions import (
    AlreadyJoinedError,
    ClientNotStarted,
    NoActiveGroupCall,
    NoMTProtoClientSet,
    TelegramServerError,
    UnMuteNeeded,
)
from ...mtproto import BridgedClient
from ...scaffold import Scaffold
from ...to_async import ToAsync
from ...types import JoinedVoiceChat
from ...types.input_stream.stream import Stream
from ..utilities.stream_params import StreamParams

py_logger = logging.getLogger("ryuzakilib")


class JoinGroupCall(Scaffold):
    async def join_group_call(
        self,
        chat_id: Union[int, str],
        stream: Optional[Stream] = None,
        invite_hash: str = None,
        join_as=None,
    ):
        if join_as is None:
            join_as = self._cache_local_peer

        chat_id = await self._resolve_chat_id(chat_id)
        self._cache_user_peer.put(chat_id, join_as)

        if self._app is None:
            raise NoMTProtoClientSet()

        if not self._is_running:
            raise ClientNotStarted()

        chat_call = await self._app.get_full_chat(
            chat_id,
        )
        if chat_call is None:
            raise NoActiveGroupCall()

        media_description = await StreamParams.get_stream_params(
            stream,
        )

        try:
            call_params: str = await ToAsync(
                self._binding.create_call,
                chat_id,
                media_description,
            )

            result_params = await self._app.join_group_call(
                chat_id,
                call_params,
                invite_hash,
                media_description.video is None,
                self._cache_user_peer.get(chat_id),
            )

            await ToAsync(
                self._binding.connect,
                chat_id,
                result_params,
            )

            participants = await self._app.get_group_call_participants(
                chat_id,
            )

            for x in participants:
                if x.user_id == BridgedClient.chat_id(
                    self._cache_local_peer,
                ):
                    self._need_unmute[chat_id] = x.muted_by_admin

            await self._on_event_update.propagate(
                "RAW_UPDATE_HANDLER",
                self,
                JoinedVoiceChat(chat_id),
            )
        except FileError:
            raise FileNotFoundError()
        except ConnectionError:
            raise AlreadyJoinedError()
        except InvalidParams:
            raise UnMuteNeeded()
        except Exception:
            raise TelegramServerError()



from json import dumps
from typing import Any, Dict, List, Union


class PyObject:
    @staticmethod
    def default(obj) -> Union[str, Dict[str, str], List[Any]]:
        if isinstance(obj, bytes):
            return repr(obj)
        if hasattr(obj, "__dict__"):
            return {
                "_": obj.__class__.__name__,
                **{attr: vars(obj)[attr] for attr in vars(obj)},
            }
        return {}

    def __str__(self) -> str:
        return dumps(
            self,
            indent=4,
            default=self.default,
            ensure_ascii=False,
        )



from typing import Any, Callable, List, Optional

from ..exceptions import InvalidMTProtoClient
from ..types.groups.group_call_participant import GroupCallParticipant
from .bridged_client import BridgedClient


class MtProtoClient:
    def __init__(
        self,
        cache_duration: int,
        client: Any,
    ):
        self._bind_client: Optional[BridgedClient] = None
        if client.__class__.__module__ == "pyrogram.client":
            from .pyrogram_client import PyrogramClient

            self._bind_client = PyrogramClient(
                cache_duration,
                client,
            )
        elif client.__class__.__module__ == "telethon.client.telegramclient":
            from .telethon_client import TelethonClient

            self._bind_client = TelethonClient(
                cache_duration,
                client,
            )
        elif client.__class__.__module__ == "hydrogram.client":
            from .hydrogram_client import HydrogramClient

            self._bind_client = HydrogramClient(
                cache_duration,
                client,
            )
        else:
            raise InvalidMTProtoClient()

    @property
    def client(self):
        client_name = self._bind_client.__class__.__name__
        if client_name == "PyrogramClient":
            return "pyrogram"
        elif client_name == "TelethonClient":
            return "telethon"
        elif client_name == "HydrogramClient":
            return "hydrogram"
        else:
            return "unknown"

    async def get_group_call_participants(
        self,
        chat_id: int,
    ) -> Optional[List[GroupCallParticipant]]:
        if self._bind_client is not None:
            return await self._bind_client.get_group_call_participants(
                chat_id,
            )
        else:
            raise InvalidMTProtoClient()

    async def join_group_call(
        self,
        chat_id: int,
        json_join: str,
        invite_hash: str,
        have_video: bool,
        join_as: Any,
    ) -> str:
        if self._bind_client is not None:
            return await self._bind_client.join_group_call(
                chat_id,
                json_join,
                invite_hash,
                have_video,
                join_as,
            )
        else:
            raise InvalidMTProtoClient()

    async def leave_group_call(
        self,
        chat_id: int,
    ):
        if self._bind_client is not None:
            await self._bind_client.leave_group_call(
                chat_id,
            )
        else:
            raise InvalidMTProtoClient()

    async def change_volume(
        self,
        chat_id: int,
        volume: int,
        participant: Any,
    ):
        if self._bind_client is not None:
            await self._bind_client.change_volume(
                chat_id,
                volume,
                participant,
            )
        else:
            raise InvalidMTProtoClient()

    async def set_call_status(
        self,
        chat_id: int,
        muted_status: Optional[bool],
        paused_status: Optional[bool],
        stopped_status: Optional[bool],
        participant: Any,
    ):
        if self._bind_client is not None:
            await self._bind_client.set_call_status(
                chat_id,
                muted_status,
                paused_status,
                stopped_status,
                participant,
            )
        else:
            raise InvalidMTProtoClient()

    async def get_full_chat(
        self,
        chat_id: int,
    ):
        if self._bind_client is not None:
            return await self._bind_client.get_full_chat(
                chat_id,
            )
        raise InvalidMTProtoClient()

    async def resolve_peer(
        self,
        user_id: int,
    ):
        if self._bind_client is not None:
            return await self._bind_client.resolve_peer(
                user_id,
            )
        raise InvalidMTProtoClient()

    async def get_id(self) -> int:
        if self._bind_client is not None:
            return await self._bind_client.get_id()
        raise InvalidMTProtoClient()

    @property
    def is_connected(self) -> bool:
        if self._bind_client is not None:
            return self._bind_client.is_connected()
        raise InvalidMTProtoClient()

    async def start(self):
        if self._bind_client is not None:
            await self._bind_client.start()
        else:
            raise InvalidMTProtoClient()

    def on_closed_voice_chat(self) -> Callable:
        if self._bind_client is not None:
            return self._bind_client.on_closed_voice_chat()
        raise InvalidMTProtoClient()

    def on_kicked(self) -> Callable:
        if self._bind_client is not None:
            return self._bind_client.on_kicked()
        raise InvalidMTProtoClient()

    def on_receive_invite(self) -> Callable:
        if self._bind_client is not None:
            return self._bind_client.on_receive_invite()
        raise InvalidMTProtoClient()

    def on_left_group(self) -> Callable:
        if self._bind_client is not None:
            return self._bind_client.on_left_group()
        raise InvalidMTProtoClient()

    def on_participants_change(self) -> Callable:
        if self._bind_client is not None:
            return self._bind_client.on_participants_change()
        raise InvalidMTProtoClient()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import base64
import json
import os
from base64 import b64decode
from base64 import b64decode as idk
from typing import Optional

import requests
from pyrogram import Client, filters
from pyrogram.types import Message

from RyuzakiLib.api.fullstack import FullStackDev
from RyuzakiLib.hackertools.blackbox import Blackbox

API_KEYS = "29db8322f22d425d7023c499610fc2419f8ff44e0bd3f63edd90d2994bf76b49"

class RendyDevChat:
    @staticmethod
    def chat_hacked(
        args: str = None,
        latest_model: str = "openai-latest",
        model_id: Optional[int] = None,
        user_id: Optional[int] = 0,
        mongo_url: Optional[str] = None,
        list_model_all: Optional[bool] = False
    ):
        if latest_model == "openai-latest":
            response_url = "https://api.safone.dev/chatgpt"
            payloads = {
                "message": args,
                "version": 3,
                "chat_mode": "assistant",
                "dialog_messages": "[{'bot': '', 'user': ''}]",
            }
            try:
                response = requests.post(
                    response_url,
                    json=payloads,
                    headers={"Content-Type": "application/json"},
                ).json()
                if not (response and "message" in response):
                    print(response)
                    raise ValueError("Invalid Response from Server")
                return response.get("message")
            except Exception as e:
                return f"Error Api {e}"
        elif latest_model == "openai-v2":
            url = "https://randydev-ryuzaki-api.hf.space/ryuzaki/chatgpt-old"
            params = {"query": args}
            response = requests.post(url, json=params)
            if response.status_code != 200:
                return f"Error status: {response.status_code}"
            check_response = response.json()
            return check_response["randydev"]["message"]
        elif latest_model == "blackbox":
            url = "https://randydev-ryuzaki-api.hf.space/ryuzaki/blackbox"
            params = {"query": args}
            response = requests.post(url, json=params)
            if response.status_code != 200:
                return f"Error status: {response.status_code}"
            check_response = response.json()
            return check_response["randydev"]["message"]
        elif latest_model == "list-model":
            if list_model_all:
                text = """
                ```python
                New Model List
                openai-latest
                openai-v2
                gemini-pro
                google-ai
                betagoogle-ai
                chatbot
                """
                return text
            else:
                return "you can check set list_model_all=True"
        elif latest_model == "gemini-pro":
            url = f"https://randydev-ryuzaki-api.hf.space/ryuzaki/gemini-ai-pro"
            payload = {
                "query": args,
                "mongo_url": mongo_url,
                "user_id": user_id,
                "is_multi_chat": True
            }
            headers = {"accept": "application/json", "api-key": API_KEYS}
            response = requests.post(url, headers=headers, json=payload)
            if response.status_code != 200:
                return f"Error status: {response.status_code}"
            check_response = response.json()
            return check_response["randydev"]["message"]
        elif latest_model == "beta-rag":
            payload = {
                "query": args,
                "user_id": user_id
            }
            headers = {"accept": "application/json"}
            response = requests.post(
                "https://randydev-ryuzaki-api.hf.space/ryuzaki/beta-rag",
                headers=headers,
                json=payload
            )
            if response.status_code != 200:
                return f"Error status: {response.status_code}"
            check_response = response.json()
            return check_response["randydev"]["message"]
        elif latest_model == "google-ai":
            url = f"https://randydev-ryuzaki-api.hf.space/ryuzaki/google-ai"
            headers = {"accept": "application/json", "api-key": API_KEYS}
            params = {"query": args}
            response = requests.post(url, headers=headers, json=params)
            if response.status_code != 200:
                return f"Error status: {response.status_code}"
            check_response = response.json()
            return check_response["randydev"]["message"]
        elif latest_model == "betagoogle-ai":
            url = f"https://randydev-ryuzaki-api.hf.space/ryuzaki/v1beta2-google-ai"
            headers = {"accept": "application/json", "api-key": API_KEYS}
            params = {"query": args}
            response = requests.post(url, headers=headers, json=params)
            if response.status_code != 200:
                return f"Error status: {response.status_code}"
            check_response = response.json()
            return check_response["randydev"]["message"]
        elif latest_model == "chatbot":
            base="aHR0cHM6Ly9hcGkuc2Fmb25lLmRldi9jaGF0Ym90",
            api_url = b64decode(base).decode("utf-8")
            params = {
                "query": args,
                "user_id": 0,
                "bot_name": "Ryuzaki Dev",
                "bot_master": "@Randydev_bot",
            }
            x = requests.get(f"{api_url}", params=params)
            if x.status_code != 200:
                return "Error api request"
            try:
                y = x.json()
                response = y["response"]
                return response
            except Exception as e:
                return f"Error {e}"

    @staticmethod
    def download_images(image_urls):
        downloaded_paths = []
        for i, url in enumerate(image_urls, start=1):
            filename = f"image_{i}.png"
            FullStackDev.fast(url, filename=filename)
        downloaded_paths.append(filename)
        return downloaded_paths

    @staticmethod
    def image_generator(args):
        url = f"https://randydev-ryuzaki-api.hf.space/ryuzaki/dalle3xl"
        headers = {"accept": "application/json", "api-key": API_KEYS}
        payload = {"query": args}
        response = requests.post(url, headers=headers, json=payload)
        if response.status_code != 200:
            return f"Error status: {response.status_code}"
        check_response = response.json()
        return check_response



from typing import Any, Callable, Dict, List, Optional


class BridgedClient:
    HANDLERS_LIST: Dict[str, List[Callable]] = {
        "CLOSED_HANDLER": [],
        "KICK_HANDLER": [],
        "INVITE_HANDLER": [],
        "LEFT_HANDLER": [],
        "PARTICIPANTS_HANDLER": [],
    }

    async def get_call(
        self,
        chat_id: int,
    ):
        pass

    async def join_group_call(
        self,
        chat_id: int,
        json_join: str,
        invite_hash: str,
        have_video: bool,
        join_as: Any,
    ) -> str:
        pass

    async def leave_group_call(
        self,
        chat_id: int,
    ):
        pass

    async def get_group_call_participants(
        self,
        chat_id: int,
    ):
        pass

    async def change_volume(
        self,
        chat_id: int,
        volume: int,
        participant: Any,
    ):
        pass

    async def set_call_status(
        self,
        chat_id: int,
        muted_status: Optional[bool],
        paused_status: Optional[bool],
        stopped_status: Optional[bool],
        participant: Any,
    ):
        pass

    async def get_participants(
        self,
        input_call: Any,
    ):
        pass

    async def resolve_peer(
        self,
        user_id: int,
    ):
        pass

    def is_connected(self) -> bool:
        pass

    async def start(self):
        pass

    @staticmethod
    def chat_id(input_peer) -> int:
        is_channel = hasattr(input_peer, "channel_id")
        is_channel_update = input_peer.__class__.__name__ == "Channel"
        is_chat = input_peer.__class__.__name__ == "Chat"
        is_user = (
            input_peer.__class__.__name__ == "PeerUser"
            or input_peer.__class__.__name__ == "InputPeerUser"
        )
        is_forbidden = input_peer.__class__.__name__ == "ChannelForbidden"
        if is_user:
            return input_peer.user_id
        elif is_channel:
            return -1000000000000 - input_peer.channel_id
        elif is_channel_update or is_forbidden:
            return -1000000000000 - input_peer.id
        elif is_chat:
            return -input_peer.id
        else:
            return -input_peer.chat_id

    def on_closed_voice_chat(self) -> Callable:
        pass

    def on_kicked(self) -> Callable:
        pass

    def on_receive_invite(self) -> Callable:
        pass

    async def get_id(self) -> int:
        pass

    def on_left_group(self) -> Callable:
        pass

    def on_participants_change(self) -> Callable:
        pass

    async def get_full_chat(self, chat_id: int):
        pass



from .user_agent import AgentInfo, UserAgent


class Browsers:
    def __init__(self):
        # CHROME BASE AGENT
        self._chrome_agent = AgentInfo(
            "Chrome",
            "94.0.4606.71",
        )

        # MOZILLA BASE AGENTS
        self._mozilla_android_agent = AgentInfo(
            "Mozilla",
            "5.0",
            "Linux",
            "Android 10",
        )
        self._mozilla_ios_agent = AgentInfo(
            "Mozilla",
            "5.0",
            "iPhone",
            "CPU iPhone OS 15_0 like Mac OS X",
        )
        self._mozilla_linux_agent = AgentInfo(
            "Mozilla",
            "5.0",
            "X11",
            "Linux x86_64",
        )
        self._mozilla_macos_agent = AgentInfo(
            "Mozilla",
            "5.0",
            "Macintosh",
            "Intel Mac OS X 11_6",
        )
        self._mozilla_windows_agent = AgentInfo(
            "Mozilla",
            "5.0",
            "Windows NT 10.0",
            "Win64",
            "x64",
        )

        # APPLE_WEBKIT BASE AGENT
        self._apple_webkit_agent = AgentInfo(
            "AppleWebKit",
            "537.36",
            "KHTML",
            "like Gecko",
        )
        self._apple_webkit_apple_agent = AgentInfo(
            "AppleWebKit",
            "605.1.15",
            "KHTML",
            "like Gecko",
        )

        # SAFARI BASE AGENT
        self._safari_agent = AgentInfo(
            "Safari",
            "537.36",
        )
        self._safari_mobile_agent = AgentInfo(
            "Mobile Safari",
            "537.36",
        )
        self._safari_macos_agent = AgentInfo(
            "Safari",
            "605.1.15",
        )
        self._safari_ios_agent = AgentInfo(
            "Safari",
            "604.1",
        )

        # EDGE BASE AGENT
        self._edge_android_agent = AgentInfo(
            "EdgA",
            "93.0.961.53",
        )
        self._edge_ios_agent = AgentInfo(
            "EdgiOS",
            "93.961.64",
        )
        self._edge_pc_agent = AgentInfo(
            "Edg",
            "94.0.992.31",
        )
        self._edge_windows_mob_agent = AgentInfo(
            "Edge",
            "40.15254.603",
        )
        self._edge_xbox_agent = AgentInfo(
            "Edge",
            "44.18363.8131",
        )

        # FIREFOX BASE AGENT
        self._firefox_default_agent = AgentInfo(
            "Firefox",
            "92.0",
        )
        self._firefox_ios_agent = AgentInfo(
            "FxiOS",
            "38.0",
        )

        # OPERA BASE AGENT
        self._opera_default_agent = AgentInfo(
            "OPR",
            "79.0.4143.66",
        )
        self._opera_mobile_agent = AgentInfo(
            "OPR",
            "63.3.3216.58675",
        )

    # CHROME
    @property
    def chrome_android(self):
        return str(
            UserAgent(
                [
                    self._mozilla_android_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_mobile_agent,
                ]
            ),
        )

    @property
    def chrome_ios(self):
        return str(
            UserAgent(
                [
                    self._mozilla_ios_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                ]
            ),
        )

    @property
    def chrome_linux(self):
        return str(
            UserAgent(
                [
                    self._mozilla_linux_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                ]
            ),
        )

    @property
    def chrome_macos(self):
        return str(
            UserAgent(
                [
                    self._mozilla_macos_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                ]
            ),
        )

    @property
    def chrome_windows(self):
        return str(
            UserAgent(
                [
                    self._mozilla_windows_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                ]
            ),
        )

    # EDGE
    @property
    def edge_android(self):
        return str(
            UserAgent(
                [
                    self._mozilla_android_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_mobile_agent,
                    self._edge_android_agent,
                ]
            ),
        )

    @property
    def edge_ios(self):
        return str(
            UserAgent(
                [
                    self._mozilla_ios_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._edge_ios_agent,
                ]
            ),
        )

    @property
    def edge_macos(self):
        return str(
            UserAgent(
                [
                    self._mozilla_macos_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._edge_pc_agent,
                ]
            ),
        )

    @property
    def edge_windows(self):
        return str(
            UserAgent(
                [
                    self._mozilla_windows_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._edge_pc_agent,
                ]
            ),
        )

    @property
    def edge_windows_mobile(self):
        return str(
            UserAgent(
                [
                    self._mozilla_windows_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._edge_windows_mob_agent,
                ]
            ),
        )

    @property
    def edge_xbox_one(self):
        return str(
            UserAgent(
                [
                    self._mozilla_windows_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._edge_xbox_agent,
                ]
            ),
        )

    # FIREFOX
    @property
    def firefox_android(self):
        return str(
            UserAgent(
                [
                    self._mozilla_android_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_mobile_agent,
                    self._firefox_default_agent,
                ]
            ),
        )

    @property
    def firefox_ios(self):
        return str(
            UserAgent(
                [
                    self._mozilla_ios_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._firefox_ios_agent,
                ]
            ),
        )

    @property
    def firefox_linux(self):
        return str(
            UserAgent(
                [
                    self._mozilla_linux_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._firefox_default_agent,
                ]
            ),
        )

    @property
    def firefox_macos(self):
        return str(
            UserAgent(
                [
                    self._mozilla_macos_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._firefox_default_agent,
                ]
            ),
        )

    @property
    def firefox_windows(self):
        return str(
            UserAgent(
                [
                    self._mozilla_windows_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._firefox_default_agent,
                ]
            ),
        )

    # OPERA
    @property
    def opera_android(self):
        return str(
            UserAgent(
                [
                    self._mozilla_android_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_mobile_agent,
                    self._opera_mobile_agent,
                ]
            ),
        )

    @property
    def opera_linux(self):
        return str(
            UserAgent(
                [
                    self._mozilla_linux_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._opera_default_agent,
                ]
            ),
        )

    @property
    def opera_macos(self):
        return str(
            UserAgent(
                [
                    self._mozilla_macos_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._opera_default_agent,
                ]
            ),
        )

    @property
    def opera_windows(self):
        return str(
            UserAgent(
                [
                    self._mozilla_windows_agent,
                    self._apple_webkit_agent,
                    self._chrome_agent,
                    self._safari_agent,
                    self._opera_default_agent,
                ]
            ),
        )

    # SAFARI
    @property
    def safari_ios(self):
        return str(
            UserAgent(
                [
                    self._mozilla_ios_agent,
                    self._apple_webkit_apple_agent,
                    self._chrome_agent,
                    self._safari_ios_agent,
                ]
            ),
        )

    @property
    def safari_macos(self):
        return str(
            UserAgent(
                [
                    self._mozilla_macos_agent,
                    self._apple_webkit_apple_agent,
                    self._chrome_agent,
                    self._safari_macos_agent,
                ]
            ),
        )



import psutil

from ...scaffold import Scaffold


class GetMaxVoiceChat(Scaffold):
    @staticmethod
    def get_max_voice_chat(consumption=5):
        core_count = psutil.cpu_count()
        return int((100 / consumption) * core_count)



import atexit
from typing import Any

from ntgcalls import NTgCalls

from .environment import Environment
from .handlers import HandlersHolder
from .methods import Methods
from .mtproto import MtProtoClient
from .scaffold import Scaffold
from .types import Cache
from .types.update_solver import UpdateSolver


class PyTgCalls(Methods, Scaffold):
    def __init__(
        self,
        app: Any,
        cache_duration: int = 120,
    ):
        super().__init__()
        self._app = MtProtoClient(
            cache_duration,
            app,
        )
        self._is_running = False
        self._env_checker = Environment(
            self._REQUIRED_PYROGRAM_VERSION,
            self._REQUIRED_TELETHON_VERSION,
            self._REQUIRED_HYDROGRAM_VERSION,
            self._app.client,
        )
        self._cache_user_peer = Cache()
        self._wait_result = UpdateSolver()
        self._on_event_update = HandlersHolder()
        self._binding = NTgCalls()

        def cleanup():
            if self._async_core is not None:
                self._async_core.cancel()

        atexit.register(cleanup)



from .decorators import Decorators
from .groups import Groups
from .stream import StreamMethods
from .utilities import Utilities


class Methods(
    Decorators,
    Groups,
    StreamMethods,
    Utilities,
):
    pass



from .change_stream import ChangeStream
from .mute_stream import MuteStream
from .pause_stream import PauseStream
from .played_time import PlayedTime
from .resume_stream import ResumeStream
from .unmute_stream import UnMuteStream


class StreamMethods(
    ChangeStream,
    MuteStream,
    PauseStream,
    PlayedTime,
    ResumeStream,
    UnMuteStream,
):
    pass



import asyncio
from asyncio import AbstractEventLoop
from typing import Any, Callable


class ToAsync:
    def __init__(self, function: Callable, *args):
        self._loop: AbstractEventLoop = asyncio.get_event_loop()
        self._function: Callable = function
        self._function_args: tuple = args

    async def _run(self):
        result: Any = await self._loop.run_in_executor(
            None,
            self._function,
            *self._function_args,
        )

        return result

    def __await__(self):
        return self._run().__await__()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


import requests
from pyrogram import Client, filters
from pyrogram.types import Message

# Instagram rapidapi : https://rapidapi.com/maatootz/api/instagram-downloader-download-instagram-videos-stories


class InstagramUrl:
    def __init__(self, apikey, link):
        self.apikey = apikey
        self.link = link

    def instagram_downloader(self):
        url = "https://instagram-downloader-download-instagram-videos-stories.p.rapidapi.com/index"
        querystring = {"url": self.link}
        headers = {
            "X-RapidAPI-Key": self.apikey,
            "X-RapidAPI-Host": "instagram-downloader-download-instagram-videos-stories.p.rapidapi.com",
        }
        response = requests.get(url, headers=headers, params=querystring)
        if response.status_code != 200:
            return "Failed api please try again"
        dataig = response.json()
        try:
            igdownloader = dataig["media"]
        except Exception as e:
            return f"Error request {e}"
        if igdownloader:
            try:
                return igdownloader
            except Exception as e:
                return f"Error request. {e}"
        else:
            return "Failed to api Instagram please try again"



from typing import Optional

from deprecation import deprecated

from .input_audio_stream import InputAudioStream
from .input_video_stream import InputVideoStream
from .stream import Stream


@deprecated(
    deprecated_in="1.0.0.dev1",
    details="This class is no longer supported." "Use pytgcalls.types.Stream instead.",
)
class InputStream(Stream):
    def __init__(
        self,
        stream_audio: Optional[InputAudioStream] = None,
        stream_video: Optional[InputVideoStream] = None,
        lip_sync: bool = False,
    ):
        super().__init__(stream_audio, stream_video)
        self.lip_sync = lip_sync



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import requests


class FullStackDev:
    @staticmethod
    def fast(url, filename, type_mode: str = "wb"):
        req = requests.get(url, allow_redirects=True)
        with open(filename, type_mode) as file:
            file.write(req.content)
        return filename



import requests


class Tiktok:
    @staticmethod
    def download(api_name, url):
        response = requests.get("{}/api/?url={}".format(api_name, url))
        if response.status_code != 200:
            return "Error Response limits"
        data_json = response.json()
        author_tiktok = data_json["data"]["author"].get("nickname") or "Unknown"
        play_tiktok = data_json["data"].get("play")
        music_tiktok = data_json["data"]["music_info"].get("play")
        return [
            play_tiktok,
            music_tiktok,
            author_tiktok
        ]



from typing import Dict

from RyuzakiLib.types.groups import GroupCallParticipant
from RyuzakiLib.types.list import List


class ParticipantList:
    def __init__(
        self,
        input_id: int,
    ):
        self._list_participants: Dict[int, GroupCallParticipant] = {}
        self.last_mtproto_update: int = 0
        self.input_id: int = input_id

    def set_participant(
        self,
        user_id: int,
        muted: bool,
        muted_by_admin: bool,
        video: bool,
        screen_sharing: bool,
        video_camera: bool,
        raised_hand: bool,
        volume: int,
    ):
        participant = GroupCallParticipant(
            user_id,
            muted,
            muted_by_admin,
            video,
            screen_sharing,
            video_camera,
            raised_hand,
            volume,
        )
        self._list_participants[user_id] = participant
        return participant

    def remove_participant(
        self,
        user_id: int,
        muted: bool,
        muted_by_admin: bool,
        video: bool,
        screen_sharing: bool,
        video_camera: bool,
        raised_hand: bool,
        volume: int,
    ):
        participant = GroupCallParticipant(
            user_id,
            muted,
            muted_by_admin,
            video,
            screen_sharing,
            video_camera,
            raised_hand,
            volume,
        )
        if user_id in self._list_participants:
            del self._list_participants[user_id]
        return participant

    def get_participants(
        self,
    ):
        return List([self._list_participants[user_id] for user_id in self._list_participants])



class BadWordsList:
    def __init__(self):
        pass

    def banned_by_google(self, file_txt: str = None, storage=False):
        if storage:
            try:
                with open(file_txt, "r") as file:
                    BLACKLIST_WORDS = [line.strip() for line in file]
                return BLACKLIST_WORDS
            except FileNotFoundError:
                print(f"Error: File '{file_txt}' not found.")
                return []
            except OSError as e:
                print(f"Error reading file: {e}")
                return []
        else:
            raise ValueError("Error: 'storage' parameter must be set to True")



import asyncio
import logging
import signal
from signal import SIGABRT, SIGINT, SIGTERM
from signal import signal as signal_fn

py_logger = logging.getLogger("ryuzakilib")


is_idling = False

# Signal number to name
signals = {
    k: v for v, k in signal.__dict__.items() if v.startswith("SIG") and not v.startswith("SIG_")
}


async def idle():
    global is_idling

    def signal_handler(signum, __):
        global is_idling
        py_logger.info(f"Stop signal received ({signals[signum]}). Exiting...")
        is_idling = False

    for s in (SIGINT, SIGTERM, SIGABRT):
        signal_fn(s, signal_handler)
    is_idling = True
    while is_idling:
        await asyncio.sleep(1)
